@@ -348,7 +348,7 @@ sub _get_desired_caps ( $self, $args ) {
             args => [    #
 
                 # https://bugs.chromium.org/p/chromium/issues/detail?id=721739
-                # headless chrome not ignoring self-signed certs
+                # headless chrome ignoring --ignore-certificate-errors
                 $args->{proxy} ? ( "--proxy-server=$args->{proxy}", '--ignore-certificate-errors' ) : (),
 
                 '--start-maximized',
@@ -359,7 +359,7 @@ sub _get_desired_caps ( $self, $args ) {
                 "--user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str,
                 '--no-sandbox',    # required for run under docker
                 defined $useragent ? "--user-agent=$useragent" : (),
-                $args->{headless} || !$MSWIN ? ( '--headless', '--disable-gpu' ) : (),
+                ( $args->{headless} || !$MSWIN ) && !$self->{wdh}->{xvfb} ? ( '--headless', '--disable-gpu' ) : (),
                 $args->{args} ? $args->{args}->@* : (),
             ],
             binary => $args->{bin} // q[],
